import { MatcherException } from '../../exceptions/matcher.exception';
import { MatchRequest } from '../dtos/match.request';
import { TimingFrequency } from './timing';

export class Time {
  _matchRequest: MatchRequest;
  _defaultMarginDuration: number;
  _defaultValidityDuration: number;
  frequency: TimingFrequency;
  fromDate: Date;
  toDate: Date;
  schedule: Array<Date>;
  marginDurations: Array<number>;

  constructor(
    matchRequest: MatchRequest,
    defaultMarginDuration: number,
    defaultValidityDuration: number,
  ) {
    this._matchRequest = matchRequest;
    this._defaultMarginDuration = defaultMarginDuration;
    this._defaultValidityDuration = defaultValidityDuration;
  }

  init() {
    this._validatePunctualDate();
    this._validateRecurrentDate();
  }

  _validatePunctualDate() {
    if (!this._matchRequest.departure && !this._matchRequest.fromDate) {
      throw new MatcherException(3, 'departure or fromDate is Required');
    }
    if (this._matchRequest.departure) {
      this.fromDate = new Date(this._matchRequest.departure);
      if (!this._isDate(this.fromDate)) {
        throw new MatcherException(3, 'Wrong departure date');
      }
      console.log(this.fromDate);
    }
  }

  _validateRecurrentDate() {
    console.log('validate recurrent date');
  }

  _isDate(date: Date) {
    return date instanceof Date && isFinite(+date);
  }
}
